@@ -42,6 +42,7 @@
 #include "lj.h"
 #include "lb.h"
 #include "lb-boundaries.h"
+#include "lb_boundaries_gpu.c"
 #include "morse.h"
 #include "buckingham.h"
 #include "tab.h"
@@ -807,6 +808,8 @@ void mpi_send_dip(int pnode, int part, double dip[3])
 #ifdef ROTATION
     convert_dip_to_quat(p->r.dip, p->r.quat, &p->p.dipm);
     convert_quat_to_quatu(p->r.quat, p->r.quatu);
+#else
+    p->p.dipm = sqrt(p->r.dip[0]*p->r.dip[0] + p->r.dip[1]*p->r.dip[1] + p->r.dip[2]*p->r.dip[2]);
 #endif
   }
   else {
@@ -827,6 +830,8 @@ void mpi_send_dip_slave(int pnode, int part)
 #ifdef ROTATION
     convert_dip_to_quat(p->r.dip, p->r.quat, &p->p.dipm);
     convert_quat_to_quatu(p->r.quat, p->r.quatu);
+#else
+    p->p.dipm = sqrt(p->r.dip[0]*p->r.dip[0] + p->r.dip[1]*p->r.dip[1] + p->r.dip[2]*p->r.dip[2]);
 #endif
   }
 
@@ -1845,9 +1850,10 @@ void mpi_bcast_constraint_slave(int node, int parm)
 /*************** REQ_BCAST_LBBOUNDARY ************/
 void mpi_bcast_lbboundary(int del_num)
 {
-#ifdef LB_BOUNDARIES
+#if defined(LB_BOUNDARIES) || defined(LB_BOUNDARIES_GPU)
   mpi_call(mpi_bcast_lbboundary_slave, 0, del_num);
 
+#ifdef LB_BOUNDARIES
   if (del_num == -1) {
     /* bcast new boundaries */
     MPI_Bcast(&lb_boundaries[n_lb_boundaries-1], sizeof(LB_Boundary), MPI_BYTE, 0, MPI_COMM_WORLD);
@@ -1857,11 +1863,17 @@ void mpi_bcast_lbboundary(int del_num)
     n_lb_boundaries = 0;
     lb_boundaries = realloc(lb_boundaries,n_lb_boundaries*sizeof(LB_Boundary));
   }
+#if defined(LB_BOUNDARIES_GPU)
+  else if (del_num == -3) {
+  //nothing, GPU code just requires to call on_boundary_change()
+  }
+#endif
   else {
     memcpy(&lb_boundaries[del_num],&lb_boundaries[n_lb_boundaries-1],sizeof(LB_Boundary));
     n_lb_boundaries--;
     lb_boundaries = realloc(lb_boundaries,n_lb_boundaries*sizeof(LB_Boundary));
   }
+#endif
 
   on_lbboundary_change();
 #endif
@@ -1869,7 +1881,9 @@ void mpi_bcast_lbboundary(int del_num)
 
 void mpi_bcast_lbboundary_slave(int node, int parm)
 {   
-#ifdef LB_BOUNDARIES
+#if defined(LB_BOUNDARIES) || defined(LB_BOUNDARIES_GPU)
+
+#if defined(LB_BOUNDARIES)
   if(parm == -1) {
     n_lb_boundaries++;
     lb_boundaries = realloc(lb_boundaries,n_lb_boundaries*sizeof(LB_Boundary));
@@ -1880,11 +1894,17 @@ void mpi_bcast_lbboundary_slave(int node, int parm)
     n_lb_boundaries = 0;
     lb_boundaries = realloc(lb_boundaries,n_lb_boundaries*sizeof(LB_Boundary));
   }
+#if defined(LB_BOUNDARIES_GPU)
+  else if (parm == -3) {
+  //nothing, GPU code just requires to call on_boundary_change()
+  }
+#endif
   else {
     memcpy(&lb_boundaries[parm],&lb_boundaries[n_lb_boundaries-1],sizeof(LB_Boundary));
     n_lb_boundaries--;
     lb_boundaries = realloc(lb_boundaries,n_lb_boundaries*sizeof(LB_Boundary));    
   }
+#endif
 
   on_lbboundary_change();
 #endif
@@ -2440,9 +2460,9 @@ void mpi_recv_fluid_border_flag(int node, int index, int *border) {
   if (node==this_node) {
     lb_local_fields_get_border_flag(index, border);
   } else {
-    int data;
+    int data = 0;
     mpi_call(mpi_recv_fluid_border_flag_slave, node, index);
-        MPI_Recv(&data, 1, MPI_INT, node, SOME_TAG, MPI_COMM_WORLD, MPI_STATUS_IGNORE);
+    MPI_Recv(&data, 1, MPI_INT, node, SOME_TAG, MPI_COMM_WORLD, MPI_STATUS_IGNORE);
     *border = data;
   }
 #endif
