@@ -430,13 +430,6 @@ void on_constraint_change()
     lb_init_boundaries();
   }
 #endif
-#ifdef LB_BOUNDARIES_GPU
-  if(this_node == 0){
-    if(lattice_switch & LATTICE_LB_GPU) {
-      lb_init_boundaries_gpu();
-    }
-  }
-#endif
 
   recalc_forces = 1;
 }
@@ -699,7 +692,7 @@ void on_parameter_change(int field)
 #ifdef LB_GPU
 if(this_node == 0){
   if (lattice_switch & LATTICE_LB_GPU) {
-    if (field == FIELD_TEMPERATURE) lb_init_gpu();
+    if (field == FIELD_TEMPERATURE) lb_reinit_parameters_gpu();
   }
 }
 #endif
@@ -720,6 +713,21 @@ void on_lb_params_change(int field) {
 }
 #endif
 
+#ifdef LB_GPU
+void on_lb_params_change_gpu(int field) {
+
+  if (field == LBPAR_AGRID) {
+    lb_init_gpu();
+  }
+  if (field == LBPAR_DENSITY) {
+    lb_reinit_fluid_gpu();
+  }
+
+  lb_reinit_parameters_gpu();
+
+}
+#endif
+
 void on_ghost_flags_change()
 {
   /* that's all we change here */
@@ -837,7 +845,7 @@ static void init_tcl(Tcl_Interp *interp)
 #endif
 #ifdef LB_GPU
   /* in lbgpu_cfile.c */
-  REGISTER_COMMAND("lbnode_exf", tclcommand_lbnode_extforce_gpu);
+  REGISTER_COMMAND("lbnode_extforce", tclcommand_lbnode_extforce_gpu);
 
   REGISTER_COMMAND("lbprint", tclcommand_lbprint_gpu);
 #endif
