@@ -1260,9 +1260,9 @@ void lb_reinit_forces() {
 
 #ifdef EXTERNAL_FORCES
     // unit conversion: force density
-      lbfields[index].force[0] = lbpar.ext_force[0]*lbpar.agrid*lbpar.agrid*tau*tau;
-      lbfields[index].force[1] = lbpar.ext_force[1]*lbpar.agrid*lbpar.agrid*tau*tau;
-      lbfields[index].force[2] = lbpar.ext_force[2]*lbpar.agrid*lbpar.agrid*tau*tau;
+      lbfields[index].force[0] = lbpar.ext_force[0]*pow(lbpar.agrid,4)*tau*tau;
+      lbfields[index].force[1] = lbpar.ext_force[1]*pow(lbpar.agrid,4)*tau*tau;
+      lbfields[index].force[2] = lbpar.ext_force[2]*pow(lbpar.agrid,4)*tau*tau;
 #else
       lbfields[index].force[0] = 0.0;
       lbfields[index].force[1] = 0.0;
@@ -1793,9 +1793,9 @@ MDINLINE void lb_apply_forces(index_t index, double* mode) {
   /* reset force */
 #ifdef EXTERNAL_FORCES
   // unit conversion: force density
-  lbfields[index].force[0] = lbpar.ext_force[0]*lbpar.agrid*lbpar.agrid*tau*tau;
-  lbfields[index].force[1] = lbpar.ext_force[1]*lbpar.agrid*lbpar.agrid*tau*tau;
-  lbfields[index].force[2] = lbpar.ext_force[2]*lbpar.agrid*lbpar.agrid*tau*tau;
+  lbfields[index].force[0] = lbpar.ext_force[0]*pow(lbpar.agrid,4)*tau*tau;
+  lbfields[index].force[1] = lbpar.ext_force[1]*pow(lbpar.agrid,4)*tau*tau;
+  lbfields[index].force[2] = lbpar.ext_force[2]*pow(lbpar.agrid,4)*tau*tau;
 #else
   lbfields[index].force[0] = 0.0;
   lbfields[index].force[1] = 0.0;
@@ -2025,13 +2025,13 @@ MDINLINE void lb_collide_stream() {
       index += 2*lblattice.halo_grid[0]; /* skip halo region */
     }
 
+    /* exchange halo regions */
+    halo_push_communication();
+
 #ifdef LB_BOUNDARIES
     /* boundary conditions for links */
     lb_bounce_back();
 #endif
-    
-    /* exchange halo regions */
-    halo_push_communication();
 
    /* swap the pointers for old and new population fields */
     double **tmp;
