@@ -37,7 +37,7 @@
 #include "tuning.h"
 #include "elc.h"
 
-#ifdef ELP3M
+#ifdef P3M
 
 /************************************************
  * variables
@@ -416,7 +416,7 @@ int tclcommand_inter_coulomb_parse_p3m_tune(Tcl_Interp * interp, int argc, char
       }
       
     } else if(ARG0_IS_S("cao")) {
-      if(! (argc > 1 && ARG1_IS_I(cao) && cao >= -1 && cao < 7)) {
+      if(! (argc > 1 && ARG1_IS_I(cao) && cao >= -1 && cao <= 7)) {
 	Tcl_AppendResult(interp, "cao expects an integer between -1 and 7",
 			 (char *) NULL);
 	return TCL_ERROR;
@@ -431,8 +431,7 @@ int tclcommand_inter_coulomb_parse_p3m_tune(Tcl_Interp * interp, int argc, char
 
     } else if (ARG0_IS_S("n_interpol")) {
       if (! (argc > 1 && ARG1_IS_I(n_interpol) && n_interpol >= 0)) {
-	Tcl_AppendResult(interp, "n_interpol expects an nonnegative integer",
-			 (char *) NULL);
+	Tcl_AppendResult(interp, "n_interpol expects an nonnegative integer", (char *) NULL);
 	return TCL_ERROR;
       }
     }
@@ -1378,7 +1377,7 @@ static double p3m_mcr_time(int mesh[3], int cao, double r_cut_iL, double alpha_L
 /** get the optimal alpha and the corresponding computation time for fixed mesh, cao. The r_cut is determined via
     a simple bisection. Returns -1 if the force evaluation does not work, -2 if there is no valid r_cut, and -3 if
     the charge assigment order is to large for this grid */
-static double p3m_mc_time(int mesh[3], int cao,
+static double p3m_mc_time(Tcl_Interp *interp, int mesh[3], int cao,
                          double r_cut_iL_min, double r_cut_iL_max, double *_r_cut_iL,
                          double *_alpha_L, double *_accuracy)
 {
@@ -1386,13 +1385,15 @@ static double p3m_mc_time(int mesh[3], int cao,
   double r_cut_iL;
   double rs_err, ks_err, mesh_size, k_cut;
   int i, n_cells;
-
+  char b1[TCL_DOUBLE_SPACE + 12],b2[TCL_DOUBLE_SPACE + 12],b3[TCL_DOUBLE_SPACE + 12];
   /* initial checks. */
   mesh_size = box_l[0]/(double)mesh[0];
   k_cut =  mesh_size*cao/2.0;
   P3M_TRACE(fprintf(stderr, "p3m_mc_time: mesh=(%d, %d, %d), cao=%d, rmin=%f, rmax=%f\n",
                    mesh[0],mesh[1],mesh[2], cao, r_cut_iL_min, r_cut_iL_max));
   if(cao >= imin(mesh[0],imin(mesh[1],mesh[2])) || k_cut >= (dmin(min_box_l,min_local_box_l) - skin)) {
+    sprintf(b2,"%-4d",mesh[0]); sprintf(b3,"%-3d",cao);
+    Tcl_AppendResult(interp, b2," ", b3," cao too large for this mesh\n", (char *) NULL);
     return -3;
   }
 
@@ -1400,6 +1401,12 @@ static double p3m_mc_time(int mesh[3], int cao,
      has infinite error estimate, as required. Therefore if the high boundary fails, there is no possible r_cut */
   if ((*_accuracy = get_accuracy(mesh, cao, r_cut_iL_max, _alpha_L, &rs_err, &ks_err)) > p3m.accuracy) {
     /* print result */
+    sprintf(b2,"%-4d",mesh[0]); sprintf(b3,"%-3d",cao);
+    Tcl_AppendResult(interp, b2," ", b3," ", (char *) NULL);
+    sprintf(b1,"%.5e",r_cut_iL_max); sprintf(b2,"%.5e",*_alpha_L); sprintf(b3,"%.5e",*_accuracy);
+    Tcl_AppendResult(interp, b1,"  ", b2,"  ",b3," ", (char *) NULL);
+    sprintf(b1,"%.3e",rs_err); sprintf(b2,"%.3e",ks_err);
+    Tcl_AppendResult(interp, b1,"  ", b2,"  accuracy not achieved\n", (char *) NULL);
     return -2;
   }
 
@@ -1411,7 +1418,7 @@ static double p3m_mc_time(int mesh[3], int cao,
       break;
 
     /* bisection */
-    if ((get_accuracy(mesh, cao, r_cut_iL, _alpha_L, &rs_err, &ks_err) > p3m.accuracy) || (*_alpha_L > box_l[0]))
+    if ((get_accuracy(mesh, cao, r_cut_iL, _alpha_L, &rs_err, &ks_err) > p3m.accuracy))
       r_cut_iL_min = r_cut_iL;
     else
       r_cut_iL_max = r_cut_iL;
@@ -1425,6 +1432,15 @@ static double p3m_mc_time(int mesh[3], int cao,
   if (coulomb.method == COULOMB_ELC_P3M && elc_params.gap_size <= 1.1*r_cut_iL*box_l[0]) {
     P3M_TRACE(fprintf(stderr, "p3m_mc_time: mesh (%d, %d, %d) cao %d r_cut %f reject r_cut %f > gap %f\n", mesh[0],mesh[1],mesh[2], cao, r_cut_iL,
                      2*r_cut_iL*box_l[0], elc_params.gap_size));
+    P3M_TRACE(fprintf(stderr, "p3m_mc_time: mesh %d cao %d r_cut %f reject r_cut %f > gap %f\n", mesh, cao, r_cut_iL,
+		      2*r_cut_iL*box_l[0], elc_params.gap_size));
+    /* print result */
+    sprintf(b2,"%-4d",mesh[0]); sprintf(b3,"%-3d",cao);
+    Tcl_AppendResult(interp, b2," ", b3," ", (char *) NULL);
+    sprintf(b1,"%.5e",r_cut_iL_max); sprintf(b2,"%.5e",*_alpha_L); sprintf(b3,"%.5e",*_accuracy);
+    Tcl_AppendResult(interp, b1,"  ", b2,"  ",b3," ", (char *) NULL);
+    sprintf(b1,"%.3e",rs_err); sprintf(b2,"%.3e",ks_err);
+    Tcl_AppendResult(interp, b1,"  ", b2,"  conflict with ELC\n", (char *) NULL);
     return -P3M_TUNE_ELCTEST;
   }
 
@@ -1434,29 +1450,40 @@ static double p3m_mc_time(int mesh[3], int cao,
     n_cells *= (int)(floor(local_box_l[i]/(r_cut_iL*box_l[0] + skin)));
   if (n_cells < min_num_cells) {
     P3M_TRACE(fprintf(stderr, "p3m_mc_time: mesh (%d, %d, %d) cao %d r_cut %f reject n_cells %d\n", mesh[0], mesh[1], mesh[2], cao, r_cut_iL, n_cells));
-
+    /* print result */
+    sprintf(b2,"%-4d",mesh[0]); sprintf(b3,"%-3d",cao);
+    Tcl_AppendResult(interp, b2," ", b3," ", (char *) NULL);
+    sprintf(b1,"%.5e",r_cut_iL_max); sprintf(b2,"%.5e",*_alpha_L); sprintf(b3,"%.5e",*_accuracy);
+    Tcl_AppendResult(interp, b1,"  ", b2,"  ",b3," ", (char *) NULL);
+    sprintf(b1,"%.3e",rs_err); sprintf(b2,"%.3e",ks_err);
+    Tcl_AppendResult(interp, b1,"  ", b2,"  radius dangerously high\n", (char *) NULL);
     return -P3M_TUNE_CUTOFF_TOO_LARGE;
   }
-  if(*_alpha_L > box_l[0]) {
-    P3M_TRACE(fprintf(stderr, "%d: alpha too large (%lf).\n", this_node, *_alpha_L/box_l[0]));
-    return -4;
-  }
   int_time = p3m_mcr_time(mesh, cao, r_cut_iL, *_alpha_L);
   if (int_time == -1) {
+    Tcl_ResetResult(interp);
+    Tcl_AppendResult(interp, "tuning failed, test integration not possible", (char *)NULL);
     return -P3M_TUNE_FAIL;
   }
 
   *_accuracy = get_accuracy(mesh, cao, r_cut_iL, _alpha_L, &rs_err, &ks_err);
 
   P3M_TRACE(fprintf(stderr, "p3m_mc_time: mesh (%d, %d, %d) cao %d r_cut %f time %f\n", mesh[0], mesh[1], mesh[2], cao, r_cut_iL, int_time));
-
+  P3M_TRACE(fprintf(stderr, "p3m_mc_time: mesh %d cao %d r_cut %f time %f\n", mesh, cao, r_cut_iL, int_time));
+  /* print result */
+  sprintf(b2,"%-4d",mesh[0]); sprintf(b3,"%-3d",cao);
+  Tcl_AppendResult(interp, b2," ", b3," ", (char *) NULL);
+  sprintf(b1,"%.5e",r_cut_iL); sprintf(b2,"%.5e",*_alpha_L); sprintf(b3,"%.5e",*_accuracy);
+  Tcl_AppendResult(interp, b1,"  ", b2,"  ",b3," ", (char *) NULL);
+  sprintf(b1,"%.3e",rs_err); sprintf(b2,"%.3e",ks_err); sprintf(b3,"%-8d",(int)int_time);
+  Tcl_AppendResult(interp, b1,"  ", b2,"  ", b3,"\n", (char *) NULL);
   return int_time;
 }
 
 /** get the optimal alpha and the corresponding computation time for fixed mesh. *cao
     should contain an initial guess, which is then adapted by stepping up and down. Returns the time
     upon completion, -1 if the force evaluation does not work, and -2 if the accuracy cannot be met */
-static double p3m_m_time(int mesh[3],
+static double p3m_m_time(Tcl_Interp *interp, int mesh[3],
                         int cao_min, int cao_max, int *_cao,
                         double r_cut_iL_min, double r_cut_iL_max, double *_r_cut_iL,
                         double *_alpha_L, double *_accuracy)
@@ -1471,7 +1498,7 @@ static double p3m_m_time(int mesh[3],
   /* the initial step sets a timing mark. If there is no valid r_cut, we can only try
      to increase cao to increase the obtainable precision of the far formula. */
   do {
-    tmp_time = p3m_mc_time(mesh, cao,  r_cut_iL_min, r_cut_iL_max, &tmp_r_cut_iL, &tmp_alpha_L, &tmp_accuracy);
+    tmp_time = p3m_mc_time(interp, mesh, cao,  r_cut_iL_min, r_cut_iL_max, &tmp_r_cut_iL, &tmp_alpha_L, &tmp_accuracy);
     /* bail out if the force evaluation is not working */
     if (tmp_time == -1) return -1;
     /* cao is too large for this grid, but still the accuracy cannot be achieved, give up */
@@ -1509,15 +1536,12 @@ static double p3m_m_time(int mesh[3],
     double dir_times[3];
     for (final_dir = -1; final_dir <= 1; final_dir += 2) {
       dir_times[final_dir + 1] = tmp_time =
-        p3m_mc_time(mesh, cao + final_dir,  r_cut_iL_min, r_cut_iL_max, &tmp_r_cut_iL, &tmp_alpha_L, &tmp_accuracy);
+        p3m_mc_time(interp, mesh, cao + final_dir,  r_cut_iL_min, r_cut_iL_max, &tmp_r_cut_iL, &tmp_alpha_L, &tmp_accuracy);
       /* bail out on errors, as usual */
       if (tmp_time == -1) return -P3M_TUNE_FAIL;
       /* in this direction, we cannot optimise, since we get into precision trouble */
       if (tmp_time < 0) continue;
 
-      /* discard invalid values for alpha */
-      if(tmp_alpha_L > box_l[0]) continue;
-
       if (tmp_time < best_time) {
 	best_time  = tmp_time;
 	*_r_cut_iL = tmp_r_cut_iL;
@@ -1557,7 +1581,7 @@ static double p3m_m_time(int mesh[3],
 
   /* move cao into the optimisation direction until we do not gain anymore. */
   for (; cao >= cao_min && cao <= cao_max; cao += final_dir) {
-    tmp_time = p3m_mc_time(mesh, cao,  r_cut_iL_min, r_cut_iL_max,
+    tmp_time = p3m_mc_time(interp, mesh, cao,  r_cut_iL_min, r_cut_iL_max,
 			   &tmp_r_cut_iL, &tmp_alpha_L, &tmp_accuracy);
     /* bail out on errors, as usual */
     if (tmp_time == -1) return -1;
@@ -1579,7 +1603,7 @@ static double p3m_m_time(int mesh[3],
   return best_time;
 }
 
-int p3m_adaptive_tune() {
+int p3m_adaptive_tune(Tcl_Interp *interp) {
   int  mesh[3] = {0, 0, 0}, tmp_mesh_points; 
   int tmp_mesh[3];
   double r_cut_iL_min, r_cut_iL_max, r_cut_iL = -1, tmp_r_cut_iL=0.0;
@@ -1588,29 +1612,51 @@ int p3m_adaptive_tune() {
   double                             accuracy = -1, tmp_accuracy=0.0;
   double                            time_best=1e20, tmp_time;
   double mesh_density = 0.0, mesh_density_min, mesh_density_max;
+  char
+    b1[3*TCL_INTEGER_SPACE + TCL_DOUBLE_SPACE + 12],
+    b2[TCL_INTEGER_SPACE + TCL_DOUBLE_SPACE + 12],
+    b3[TCL_INTEGER_SPACE + TCL_DOUBLE_SPACE + 17];
 
+  if (skin == -1) {
+    Tcl_AppendResult(interp, "p3m cannot be tuned, since the skin is not yet set", (char *) NULL);
+    return TCL_ERROR;
+  }
 
-  P3M_TRACE(fprintf(stderr,"%d: p3m_adaptive_tune\n",this_node));
-  P3M_TRACE(fprintf(stderr,"%d: desired accuracy: %lf\n", this_node, p3m.accuracy));
   /* preparation */
   mpi_bcast_event(P3M_COUNT_CHARGES);
+  /* Print Status */
+  sprintf(b1,"%.5e",p3m.accuracy);
+  Tcl_AppendResult(interp, "P3M tune parameters: Accuracy goal = ",b1,"\n", (char *) NULL);
+  Tcl_PrintDouble(interp, box_l[0], b1);
+
+    sprintf(b2,"%d",p3m_sum_qpart);
+  Tcl_PrintDouble(interp, p3m_sum_q2, b3);
+  Tcl_AppendResult(interp, "System: box_l = ",b1,", # charged part = ",b2," Sum[q_i^2] = ",b3,"\n", (char *) NULL);
+
+
+  if (p3m_sum_qpart == 0) {
+    Tcl_AppendResult(interp, "no charged particles in the system, cannot tune P3M", (char *) NULL);
+    return (TCL_ERROR);
+  }
+
 
  /* parameter ranges */
   /* if at least the number of meshpoints in one direction is not set, we have to tune it. */
   if (p3m.mesh[0] == 0 || p3m.mesh[1] == 0 || p3m.mesh[2] == 0) {
     tmp_mesh_points = p3m_sum_qpart;
-    mesh_density_min = pow((box_l[0] * box_l[1] * box_l[2]) / p3m_sum_qpart, 1.0/3.0);
+    mesh_density_min = pow(p3m_sum_qpart / (box_l[0] * box_l[1] * box_l[2]) , 1.0/3.0) - 0.1;
     mesh_density_max = 256 / pow(box_l[0] * box_l[1] * box_l[2], 1.0/3.0);
     /* this limits the tried meshes if the accuracy cannot
        be obtained with smaller meshes, but normally not all these
        meshes have to be tested */
     /* avoid using more than 1 GB of FFT arrays (per default, see config.h) */
-    //    mesh_max = imin(mesh_max, P3M_MAX_MESH*P3M_MAX_MESH*P3M_MAX_MESH);
 
     P3M_TRACE(fprintf(stderr, "%d: starting with meshdensity %lf, using at most %lf.\n", this_node, mesh_density_min, mesh_density_max));
 
   } else {
     mesh_density = mesh_density_min = mesh_density_max = p3m.mesh[0] / box_l[0];
+    sprintf(b1, "%d %d %d", p3m.mesh[0], p3m.mesh[1], p3m.mesh[2]);
+    Tcl_AppendResult(interp, "fixed mesh ", b1, "\n", (char *)NULL);
   }
 
    
@@ -1623,6 +1669,9 @@ int p3m_adaptive_tune() {
   }
   else {
     r_cut_iL_min = r_cut_iL_max = p3m.r_cut_iL;
+    sprintf(b1, "%f", p3m.r_cut_iL);
+    Tcl_AppendResult(interp, "fixed r_cut_iL ", b1, "\n", (char *)NULL);
+    r_cut_iL_min = r_cut_iL_max = p3m.r_cut_iL;
   }
 
   if(p3m.cao == 0) {
@@ -1632,8 +1681,13 @@ int p3m_adaptive_tune() {
   }
   else {
     cao_min = cao_max = cao = p3m.cao;
+    sprintf(b1, "%d", p3m.cao);
+    Tcl_AppendResult(interp, "fixed cao ", b1, "\n", (char *)NULL);
+    cao_min = cao_max = cao = p3m.cao;
   }
 
+  Tcl_AppendResult(interp, "mesh cao r_cut_iL     alpha_L      err          rs_err     ks_err     time [ms]\n", (char *) NULL);
+
   /* mesh loop */
   /* we're tuning the density of mesh points, which is the same in every direction. */
   for (mesh_density=mesh_density_min;mesh_density<=mesh_density_max;mesh_density+=0.1) {
@@ -1652,8 +1706,7 @@ int p3m_adaptive_tune() {
     if(tmp_mesh[2] % 2)
       tmp_mesh[2]++;
 
-
-    tmp_time = p3m_m_time(tmp_mesh,
+    tmp_time = p3m_m_time(interp, tmp_mesh,
 			  cao_min, cao_max, &tmp_cao,
 			  r_cut_iL_min, r_cut_iL_max, &tmp_r_cut_iL,
 			  &tmp_alpha_L, &tmp_accuracy); 
@@ -1686,9 +1739,10 @@ int p3m_adaptive_tune() {
     }
   }
   
-  P3M_TRACE(fprintf(stderr,"finshed tuning, best time: %lf\n", time_best));
+  P3M_TRACE(fprintf(stderr,"%d: finshed tuning, best time: %lf\n", this_node,time_best));
   if(time_best == 1e20) {
-    return -1;
+    Tcl_AppendResult(interp, "** failed to tune P3M parameters to required accuracy", (char *) NULL);
+    return (TCL_ERROR);
   }
 
   /* set tuned p3m parameters */
@@ -1706,7 +1760,15 @@ int p3m_adaptive_tune() {
 
   P3M_TRACE(print_p3m());
 
-  return 0;
+  /* Tell the user about the outcome */
+  Tcl_AppendResult(interp, "\nresulting parameters:\n", (char *) NULL);
+  sprintf(b2,"%-4d",mesh[0]); sprintf(b3,"%-3d",cao);
+  Tcl_AppendResult(interp, b2," ", b3," ", (char *) NULL);
+  sprintf(b1,"%.5e",r_cut_iL); sprintf(b2,"%.5e",alpha_L); sprintf(b3,"%.5e",accuracy);
+  Tcl_AppendResult(interp, b1,"  ", b2,"  ", b3,"  ", (char *) NULL);
+  sprintf(b3,"                 %-8d",(int)time_best);
+  Tcl_AppendResult(interp, b3, (char *) NULL);
+  return (TCL_OK);
 }
   
 
@@ -1742,7 +1804,7 @@ int tclcommand_inter_coulomb_print_p3m_adaptive_tune_parameters(Tcl_Interp *inte
     return (TCL_ERROR);
   }
   
-  if(p3m_adaptive_tune()) {  
+  if(p3m_adaptive_tune(interp) == TCL_ERROR) {  
     Tcl_AppendResult(interp, "failed to tune P3M parameters to required accuracy", (char *) NULL);
     return (TCL_ERROR);
   }
@@ -2308,5 +2370,5 @@ void p3m_print_p3m_struct(p3m_struct ps) {
 	  ps.a[0],ps.a[1],ps.a[2],ps.ai[0],ps.ai[1],ps.ai[2]);
 }
 
-#endif /* of ELP3M */
+#endif /* of P3M */
 
